package net.sf.basedb.examples.extensions;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.sf.basedb.clients.web.Base;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.core.User;

/**
	Example of a custom servlet that is part of an extension.
	The servlet will output a simple message, that can be be
	redefined by changing the "template" initialisation parameter.
	
	@author nicklas
*/
public class HelloWorldServlet 
	extends HttpServlet 
{

	private static final long serialVersionUID = -7225081541778867323L;
	private String template;
	
	public HelloWorldServlet()
	{}

	@Override
	public void init()
		throws ServletException
	{
		ServletConfig cfg = getServletConfig();
		template = cfg.getInitParameter("template");
		if (template == null) template = "Hello {user}.";
	}
	
	@Override
	protected void doGet(HttpServletRequest request, HttpServletResponse response)
		throws ServletException, IOException
	{
		final SessionControl sc = Base.getExistingSessionControl(request, true);
		final DbControl dc = sc.newDbControl();

		try
		{
			User current = User.getById(dc, sc.getLoggedInUserId());
			PrintWriter out = response.getWriter();
			out.print(template.replace("{user}", current.getName()));
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}
	
	@Override
	protected void doPost(HttpServletRequest req, HttpServletResponse resp)
		throws ServletException, IOException
	{
		doGet(req, resp);
	}
}
